/*

This takes a color, a correction map and outputs a new corrected color.
The correction map needs to have 32 cells of 16x16.
Each cell contains Red on X and Green on Y and Blue is incremented for each cell.
NOTE: The map needs to be declared as clamped and bilinear filtered and no mipmaps.

*/

void colorCorrection(
in lowp vec3 color, 					//the original color
in lowp sampler2D colorCorrectionMap, 	//the correction table
out lowp vec3 correctedColor)			//the corrected color
{
	const highp float cellSize = 16.0;
	const highp float cellCount = 32.0;

	const highp float texWidth = cellSize * cellCount;
	const highp float pixelSizeX = 1.0 / texWidth;
	const highp float pixelSizeY = 1.0 / cellSize;
	const highp float pixelHalfSizeX = pixelSizeX * 0.5;
	const highp float pixelHalfSizeY = pixelSizeY * 0.5;

	highp vec3 hc = color;
	highp float r = hc.r * (pixelSizeX * (cellSize - 2.0)) + pixelHalfSizeX;
	highp float g = hc.g * (pixelSizeY * (cellSize - 1.0)) + pixelHalfSizeY;
	highp float b = floor(hc.b * (cellCount - 1.0) + 0.5) * (cellSize * pixelSizeX);

	correctedColor = texture2D(colorCorrectionMap, vec2(r + b, g)).rgb;

}