void diffuseLambert(
	in highp vec3 lightDir, 	//normalized light direction
	in highp vec3 normal,	 	//normalized surface normal
	out highp float nl,			//lightDir DOT normal
	out highp float intensity 	//diffuse intensity
	)
{
	nl = -dot(normal, lightDir);
	intensity = max(nl, 0.0);
}

void diffuseHalfLambert(
	in highp vec3 lightDir, 	//normalized light direction
	in highp vec3 normal,	 	//normalized surface normal
	out highp float nl,			//lightDir DOT normal
	out highp float intensity 	//diffuse intensity
	)
{
	nl = -dot(normal, lightDir);
	highp float hl  = nl*0.5 + 0.5;
	intensity = hl*hl;
}

void diffuseFullLambert(
	in highp vec3 lightDir, 	//normalized light direction
	in highp vec3 normal,	 	//normalized surface normal
	out highp float nl,			//lightDir DOT normal
	out highp float intensity 	//diffuse intensity
	)
{
	nl = -dot(normal, lightDir);
	intensity  = (nl + 1.0)*0.5;
}

void specularBlinn(
	in highp vec3 lightDir, 	//normalized light direction
	in highp vec3 normal,		//normalized surface normal
	in highp vec3 eyeDirection,	//normalized eye direction
	in highp float specularExponent,//specular exponent
	out highp float intensity	//speculat intensity
	)
{
	highp vec3 halfAngle = normalize(lightDir + eyeDirection);
	intensity = pow(max(-dot(halfAngle, normal), 0.0), specularExponent);
}

void specularPhong(
	in highp vec3 lightDir, 	//normalized light direction
	in highp vec3 reflection,	//normalized reflection vector
	in highp float specularExponent,//specular exponent
	out highp float intensity	//speculat intensity
	)
{
	intensity = pow(max(-dot(reflection, lightDir), 0.0), specularExponent);
}
